@@ -64,7 +64,8 @@ class Netlink(utilsBase):
                 'sit': self._link_dump_info_data_iptun_tunnel,
                 'ip6tnl': self._link_dump_info_data_iptun_tunnel,
                 'vti': self._link_dump_info_data_vti_tunnel,
-                'vti6': self._link_dump_info_data_vti_tunnel
+                'vti6': self._link_dump_info_data_vti_tunnel,
+                'xfrm': self._link_dump_info_data_xfrm
             }
 
         except Exception as e:
@@ -221,6 +222,17 @@ class Netlink(utilsBase):
         except Exception as e:
             raise Exception('netlink: %s: cannot create macvlan %s: %s'
                             % (ifacename, macvlan_ifacename, str(e)))
+    
+    def link_add_xfrm(self, ifacename, xfrm_ifacename, xfrm_id):
+        self.logger.info('%s: netlink: ip link add %s type xfrm dev %s if_id %s'
+                         % (xfrm_ifacename, xfrm_ifacename, ifacename, xfrm_id))
+        if ifupdownflags.flags.DRYRUN: return
+        ifindex = self.get_iface_index(ifacename)
+        try:
+            return self._nlmanager_api.link_add_xfrm(ifindex, xfrm_ifacename, xfrm_id)
+        except Exception as e:
+            raise Exception('netlink: %s: cannot create xfrm %s id %s: %s'
+                            % (ifacename, xfrm_ifacename, xfrm_id, str(e)))
 
     def link_set_updown(self, ifacename, state):
         self.logger.info('%s: netlink: ip link set dev %s %s'
@@ -242,11 +254,11 @@ class Netlink(utilsBase):
             raise Exception('netlink: cannot set link %s protodown %s: %s'
                             % (ifacename, state, str(e)))
 
-    def link_add_bridge(self, ifname):
+    def link_add_bridge(self, ifname, mtu=None):
         self.logger.info('%s: netlink: ip link add %s type bridge' % (ifname, ifname))
         if ifupdownflags.flags.DRYRUN: return
         try:
-            return self._nlmanager_api.link_add_bridge(ifname)
+            return self._nlmanager_api.link_add_bridge(ifname, mtu=mtu)
         except Exception as e:
             raise Exception('netlink: cannot create bridge %s: %s' % (ifname, str(e)))
 
@@ -273,7 +285,7 @@ class Netlink(utilsBase):
                             % (ifacename, vlanid, str(e)))
 
     def link_add_vxlan(self, ifacename, vxlanid, local=None, dstport=VXLAN_UDP_PORT,
-                       group=None, learning=True, ageing=None, physdev=None):
+                       group=None, learning=True, ageing=None, physdev=None, ttl=None):
         cmd = 'ip link add %s type vxlan id %s dstport %s' % (ifacename,
                                                               vxlanid,
                                                               dstport)
@@ -282,6 +294,10 @@ class Netlink(utilsBase):
         cmd += ' remote %s' % group if group else ' noremote'
         cmd += ' nolearning' if not learning else ''
         cmd += ' dev %s' % physdev if physdev else ''
+
+        if ttl is not None:
+            cmd += ' ttl %s' % ttl
+
         self.logger.info('%s: netlink: %s' % (ifacename, cmd))
         if ifupdownflags.flags.DRYRUN: return
         try:
@@ -294,7 +310,8 @@ class Netlink(utilsBase):
                                                       group=group,
                                                       learning=learning,
                                                       ageing=ageing,
-                                                      physdev=physdev)
+                                                      physdev=physdev,
+                                                      ttl=ttl)
         except Exception as e:
             raise Exception('netlink: %s: cannot create vxlan %s: %s'
                             % (ifacename, vxlanid, str(e)))
@@ -539,6 +556,14 @@ class Netlink(utilsBase):
             "tunnel-physdev": self.get_iface_name(tunnel_link_ifindex) if tunnel_link_ifindex else ""
         }
 
+    def _link_dump_info_data_xfrm(self, ifname, linkdata):
+        xfrm_physdev_link_ifindex = linkdata.get(Link.IFLA_XFRM_LINK)
+
+        return {
+            'xfrm-id': str(linkdata.get(Link.IFLA_XFRM_IF_ID, '')),
+            'xfrm-physdev': self.get_iface_name(xfrm_physdev_link_ifindex) if xfrm_physdev_link_ifindex else ""
+        }
+
     def _link_dump_linkinfo(self, link, dump):
         linkinfo = link.attributes[Link.IFLA_LINKINFO].get_pretty_value(dict)
 
