@@ -637,7 +637,7 @@ class NetlinkManager(object):
         link.build_message(self.sequence.next(), self.pid)
         return self.tx_nlpacket_get_response(link)
 
-    def _link_add(self, ifindex, ifname, kind, ifla_info_data):
+    def _link_add(self, ifindex, ifname, kind, ifla_info_data, mtu=None):
         """
         Build and TX a RTM_NEWLINK message to add the desired interface
         """
@@ -651,6 +651,9 @@ class NetlinkManager(object):
         if ifindex:
             link.add_attribute(Link.IFLA_LINK, ifindex)
 
+        if mtu:
+            link.add_attribute(Link.IFLA_MTU, mtu)
+
         link.add_attribute(Link.IFLA_LINKINFO, {
             Link.IFLA_INFO_KIND: kind,
             Link.IFLA_INFO_DATA: ifla_info_data
@@ -658,8 +661,8 @@ class NetlinkManager(object):
         link.build_message(self.sequence.next(), self.pid)
         return self.tx_nlpacket_get_response(link)
 
-    def link_add_bridge(self, ifname, ifla_info_data={}):
-        return self._link_add(ifindex=None, ifname=ifname, kind='bridge', ifla_info_data=ifla_info_data)
+    def link_add_bridge(self, ifname, ifla_info_data={}, mtu=None):
+        return self._link_add(ifindex=None, ifname=ifname, kind='bridge', ifla_info_data=ifla_info_data, mtu=mtu)
 
     def link_add_vlan(self, ifindex, ifname, vlanid, vlan_protocol=None):
         """
@@ -696,6 +699,18 @@ class NetlinkManager(object):
         """
         return self._link_add(ifindex, ifname, 'macvlan', {Link.IFLA_MACVLAN_MODE: Link.MACVLAN_MODE_PRIVATE})
 
+    def link_add_xfrm(self, physdev, xfrm_ifname, xfrm_id):
+        """
+        ifindex is the index of the parent interface that this sub-interface
+        is being added to
+        """
+        ifla_info_data = {
+            Link.IFLA_XFRM_IF_ID: int(xfrm_id),
+            Link.IFLA_XFRM_LINK: int(physdev)
+        }
+        
+        return self._link_add(ifindex=None, ifname=xfrm_ifname, kind='xfrm', ifla_info_data=ifla_info_data)
+
     def vlan_get(self, filter_ifindex=None, filter_vlanid=None, compress_vlans=True):
         """
         filter_ifindex should be a tuple if interface indexes, this is a whitelist filter
@@ -964,7 +979,7 @@ class NetlinkManager(object):
         return self.tx_nlpacket_get_response(nbr)
 
     def link_add_vxlan(self, ifname, vxlanid, dstport=None, local=None,
-                       group=None, learning=True, ageing=None, physdev=None):
+                       group=None, learning=True, ageing=None, physdev=None, ttl=None):
 
         debug = RTM_NEWLINK in self.debug
 
@@ -977,6 +992,7 @@ class NetlinkManager(object):
             info_data[Link.IFLA_VXLAN_GROUP] = group
 
         info_data[Link.IFLA_VXLAN_LEARNING] = int(learning)
+        info_data[Link.IFLA_VXLAN_TTL] = ttl
 
         if ageing:
             info_data[Link.IFLA_VXLAN_AGEING] = int(ageing)
